@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -167,18 +167,20 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
 If you are just starting up with POS RECEIPT Printers, you must first refer to L<Printer::ESCPOS::Manual> to get started.
 
 Printer::ESCPOS provides four different types of printer connections to talk to a ESCPOS printer.
-As of v0.012 I<driverType> B<Serial>, B<Network>, B<File> and B<USB> are all implemented in this module. B<USB> I<driverType> is not supported prior to v0.012.
+As of v0.012 I<driverType> B<Serial>, B<Network>, B<File> and B<USB> are all implemented in this module. B<USB> I<driverType>
+is not supported prior to v0.012.
 
 =head2 USB Printer
 
-B<USB> I<driverType> allows you to talk to your Printer using the I<vendorId> and I<productId> values for your printer. These can be retrieved using lsusb command
+B<USB> I<driverType> allows you to talk to your Printer using the I<vendorId> and I<productId> values for your printer.
+These can be retrieved using lsusb command
 
      shantanu@shantanu-G41M-ES2L:~/github$ lsusb
      . . .
@@ -200,6 +202,12 @@ For USB Printers L<Printer::ESCPOS> uses a default I<endPoint> of 0x01 and a def
          productId      => $productId,
      );
  
+     use GD;
+     my $img = newFromGif GD::Image('header.gif') || die "Error $!";
+     $device->printer->image($img); # Takes a GD image object
+ 
+     $device->printer->qr("Don't Panic!"); # Print a QR Code
+ 
      $device->printer->printAreaWidth( nL => 0, nH => 1);
      $device->printer->text("Print Area Width Modified\n");
      $device->printer->printAreaWidth(); # Reset to default
@@ -257,7 +265,9 @@ you have configured your printer
 Use the B<Serial> I<driverType> for local printer connected on serial port(or a printer connected via
 a physical USB port in USB to Serial mode), check syslog(Usually under E<sol>varE<sol>logE<sol>syslog)
 for what device file was created for your printer when you connect it to your system(For
-plug and play printers).
+plug and play printers). You may also use a Windows port name like 'COM1', 'COM2' etc. as
+deviceFilePath param when running this under windows. The Device::SerialPort claims to support this
+syntax. (Drop me a email if you are able to make it work in windows as I have not tested it out yet)
 
      use Printer::ESCPOS;
      use Data::Dumper; # Just to get dumps of status functions supported for Serial driverType.
@@ -303,7 +313,9 @@ printerStatus, offlineStatus, errorStatus or paperSensorStatus functions
 
 =head1 DESCRIPTION
 
-You can use this module for all your ESC-POS Printing needs. If some of your printer's functions are not included, you may extend this module by adding specialized funtions for your printer in it's own subclass. Refer to L<Printer::ESCPOS::Roles::Profile> and L<Printer::ESCPOS::Profiles::Generic>
+You can use this module for all your ESC-POS Printing needs. If some of your printer's functions are not included, you
+may extend this module by adding specialized funtions for your printer in it's own subclass. Refer to
+L<Printer::ESCPOS::Roles::Profile> and L<Printer::ESCPOS::Profiles::Generic>
 
 =head1 ATTRIBUTES
 
@@ -352,17 +364,22 @@ File driver type:
 
 =head2 profile
 
-There are minor differences in ESC POS printers across different brands and models in terms of specifications and extra features. For using special features of a particular brand you may create a sub class in the name space Printer::ESCPOS::Profiles::* and load your profile here. I would recommend extending the Generic Profile( L<Printer::ESCPOS::Profiles::Generic> ).
+There are minor differences in ESC POS printers across different brands and models in terms of specifications and extra
+features. For using special features of a particular brand you may create a sub class in the name space
+Printer::ESCPOS::Profiles::* and load your profile here. I would recommend extending the Generic
+Profile( L<Printer::ESCPOS::Profiles::Generic> ).
 Use the following classes as examples.
 L<Printer::ESCPOS::Profiles::Generic>
 L<Printer::ESCPOS::Profiles::SinocanPSeries>
 
-Note that your driver class will have to implement the Printer::ESCPOS::Roles::Profile Interface. This is a L<Moo::Role> and can be included in your class with the following line.
+Note that your driver class will have to implement the Printer::ESCPOS::Roles::Profile Interface. This is a L<Moo::Role>
+and can be included in your class with the following line.
 
     use Moo;
     with 'Printer::ESCPOS::Roles::Profile';
 
-By default the generic profile is loaded but if you have written your own Printer::ESCPOS::Profile::* class and want to override the generic class pass the I<profile> Param during object creation.
+By default the generic profile is loaded but if you have written your own Printer::ESCPOS::Profile::* class and want to
+override the generic class pass the I<profile> Param during object creation.
 
     my $device = Printer::ESCPOS->new(
         driverType => 'Network',
@@ -375,7 +392,10 @@ The above $device object will use the Printer::ESCPOS::Profile::USERCUSTOM profi
 
 =head2 deviceFilePath
 
-File path for UNIX device file. e.g. "/dev/ttyACM0" this is a mandatory parameter if you are using B<File> or B<Serial> I<driverType>.
+File path for UNIX device file. e.g. "/dev/ttyACM0", or port name for Win32 (untested) like 'COM1', COM2' etc. This is a
+mandatory parameter if you are using B<File> or B<Serial> I<driverType>. I haven't had a chance to test this on windows
+so if you are able to successfully use this with a serial port on windows, drop me a email to let me know that I got it
+right :)
 
 =head2 portName
 
@@ -383,31 +403,38 @@ Win32 serial port name
 
 =head2 deviceIP
 
-Contains the IP address of the device when its a network printer. The module creates L<IO:Socket::INET> object to connect to the printer. This can be passed in the constructor.
+Contains the IP address of the device when its a network printer. The module creates L<IO:Socket::INET> object to
+connect to the printer. This can be passed in the constructor.
 
 =head2 devicePort
 
-Contains the network port of the device when its a network printer. The module creates L<IO:Socket::INET> object to connect to the printer. This can be passed in the constructor.
+Contains the network port of the device when its a network printer. The module creates L<IO:Socket::INET> object to
+connect to the printer. This can be passed in the constructor.
 
 =head2 baudrate
 
-When used as a local serial device you can set the I<baudrate> of the printer too. Default (38400) will usually work, but not always.
+When used as a local serial device you can set the I<baudrate> of the printer too. Default (38400) will usually work,
+but not always.
 
 =head2 serialOverUSB
 
-Set this value to 1 if you are connecting your printer using the USB Cable but it shows up as a serial device and you are using the B<Serial> driver.
+Set this value to 1 if you are connecting your printer using the USB Cable but it shows up as a serial device and you
+are using the B<Serial> driver.
 
 =head2 vendorId
 
-This is a required param for B<USB> I<driverType>. It contains the USB printer's Vendor ID when using B<USB> I<driverType>. Use lsusb command to get this value for your printer.
+This is a required param for B<USB> I<driverType>. It contains the USB printer's Vendor ID when using B<USB>
+I<driverType>. Use lsusb command to get this value for your printer.
 
 =head2 productId
 
-This is a required param for B<USB> I<driverType>. It contains the USB printer's product Id when using B<USB> I<driverType>. Use lsusb command to get this value for your printer.
+This is a required param for B<USB> I<driverType>. It contains the USB printer's product Id when using B<USB>
+I<driverType>. Use lsusb command to get this value for your printer.
 
 =head2 endPoint
 
-This is a optional param for B<USB> I<driverType>. It contains the USB endPoint for L<Device::USB> to write to if the value is not 0x01 for your printer. Get it using the following command:
+This is a optional param for B<USB> I<driverType>. It contains the USB endPoint for L<Device::USB> to write to if the
+value is not 0x01 for your printer. Get it using the following command:
 
     shantanu@shantanu-G41M-ES2L:~$ sudo lsusb -vvv -d 1504:0006 | grep bEndpointAddress | grep OUT
             bEndpointAddress     0x01  EP 1 OUT
@@ -443,11 +470,13 @@ L<Printer::ESCPOS::Manual>
 
 =item 1.
 
-Create a device object $device by providing parameters for one of the supported printer types. Call $device-E<gt>printer-E<gt>init to initialize the printer.
+Create a device object $device by providing parameters for one of the supported printer types. Call
+$device-E<gt>printer-E<gt>init to initialize the printer.
 
 =item 2.
 
-call text() and other Text formatting functions on $device-E<gt>printer for the data to be sent to the printer. Make sure to end it all with a linefeed $device-E<gt>printer-E<gt>lf().
+call text() and other Text formatting functions on $device-E<gt>printer for the data to be sent to the printer. Make sure
+to end it all with a linefeed $device-E<gt>printer-E<gt>lf().
 
 =item 3.
 
@@ -457,7 +486,9 @@ Then call the print() method to dispatch the sequences from the module buffer to
 
      $device->printer->print()
 
-Note: While you may call print() after every single command code, this is not advisable as some printers tend to choke up if you send them too many print commands in quick succession. To avoid this, aggregate the data to be sent to the printer with text() and other text formatting functions and then send it all in one go using print() at the very end.
+Note: While you may call print() after every single command code, this is not advisable as some printers tend to choke
+up if you send them too many print commands in quick succession. To avoid this, aggregate the data to be sent to the
+printer with text() and other text formatting functions and then send it all in one go using print() at the very end.
 
 =head1 NOTES
 
@@ -465,7 +496,8 @@ Note: While you may call print() after every single command code, this is not ad
 
 =item *
 
-In Serial mode if the printer prints out garbled characters instead of proper text, try specifying the baudrate parameter when you create the printer object. The default baudrate is set at 38400
+In Serial mode if the printer prints out garbled characters instead of proper text, try specifying the baudrate
+parameter when you create the printer object. The default baudrate is set at 38400
 
 =back
 
