@@ -13,7 +13,7 @@ package Printer::ESCPOS::Manual;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 1;
 
@@ -27,9 +27,9 @@ Printer::ESCPOS::Manual - Manual for Printing POS Receipts using L<Printer::ESCP
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
-=head1 SYNOPSIS 
+=head1 SYNOPSIS
 
 =head2 BASIC USAGE
 
@@ -41,8 +41,8 @@ version 0.025
          deviceFilePath => '/dev/ttyACM0'
      );
  
-     # All Printers have their own initialization 
-     # recommendations(Cleaning buffers etc.). Run 
+     # All Printers have their own initialization
+     # recommendations(Cleaning buffers etc.). Run
      # this command to let the module do this for you.
      $device->printer->init();
  
@@ -57,9 +57,9 @@ version 0.025
  
  
      # Add a cut paper command at the end to cut the receipt
-     # This command will be ignored by your printer if it 
-     # doesn't have a paper cutter on it 
-     $device->printer->cutPaper(); 
+     # This command will be ignored by your printer if it
+     # doesn't have a paper cutter on it
+     $device->printer->cutPaper();
  
  
      # Send the Prepared data to the printer.
@@ -127,13 +127,14 @@ the driver uses 38400 as default baudrate. If necessary you can change this valu
          baudrate       => 9600,
      );
 
-If your printer is not printing properly when connected on physical serial port try setting the flag I<serialOverUSB> to B<0> to tell L<Printer::ESCPOS> to use special buffer management optimizations for physical serial ports
+If your printer is not printing properly when connected on physical serial port try setting the flag I<serialOverUSB> to
+B<0> to tell L<Printer::ESCPOS> to use special buffer management optimizations for physical serial ports
 
      my $device = Printer::ESCPOS->new(
          driverType     => 'Serial',
          deviceFilePath => '/dev/ttyACM0',
          baudrate       => 9600,
-         serialOverUSB  => 0 
+         serialOverUSB  => 0
      );
 
 =head3 NETWORK PRINTER
@@ -150,7 +151,12 @@ This is a I<driverType> for printers connected over a network.
 =head3 BASIC DEVICE FILE Driver
 
 The Mandatory parameters for a B<File> I<driverType> are I<driverType>( B<File> ) and I<deviceFilePath>
-This Driver is included for those instances when your printing needs are simple(You don't want to check the printer for printer status etc. and are only interested in pushing data to the printer for printing) and B<Serial> driver type is just refusing to work altogether. In this I<driverType> the data is written directly to the printer device file and from there sent to the printer. This is the basic text method for ESCPOS printers and it almost always works but it doesn't allow you to read Printer Status which might not be a deal breaker for most people. This I<driverType> can also be used for Printers which connect on USB ports but don't show up as Serial devices in syslog
+This Driver is included for those instances when your printing needs are simple(You don't want to check the printer for
+printer status etc. and are only interested in pushing data to the printer for printing) and B<Serial> driver type is
+just refusing to work altogether. In this I<driverType> the data is written directly to the printer device file and from
+there sent to the printer. This is the basic text method for ESCPOS printers and it almost always works but it doesn't
+allow you to read Printer Status which might not be a deal breaker for most people. This I<driverType> can also be used
+for Printers which connect on USB ports but don't show up as Serial devices in syslog
 
      my $device = Printer::ESCPOS->new(
          driverType     => 'File',
@@ -159,9 +165,37 @@ This Driver is included for those instances when your printing needs are simple(
 
 =head2 PREPARING FORMATTED TEXT FOR PRINTER
 
-In all the methods described below its assumed that variable C<<< $device >>> has been initialized using the appropriate connection to the printer with one of the driverTypes mentioned above.
+In all the methods described below its assumed that variable C<<< $device >>> has been initialized using the appropriate
+connection to the printer with one of the driverTypes mentioned above.
 The following methods prepare the text and text formatting data to be sent to the printer.
 
+=head3 qr
+
+Prints a qr code to the printer. In Generic profile, this creates a QR Code image using LE<lt>GD::Barcode::QRcodeE<gt>. A native
+implementation may be created using a printer model specific profile.
+
+     $device->printer->qr('Print this QR Code');
+     $device->printer->qr('WIFI:T:WPA;S:ShantanusWifi;P:wifipasswordhere;;')  # Create a QR code for connecting to a Wifi
+
+You may also pass in optional QR Code format parameters like Ecc, Version and moduleSize. Read more about these params
+at http:E<sol>E<sol>www.qrcode.comE<sol>enE<sol>aboutE<sol>version.html.
+
+     my $ecc = 'L'; # Default value
+     my $version = 5; # Default value
+     my $moduleSize = 3; # Default value
+     $device->printer->qr("Don't Panic!", $ecc, $version, $moduleSize);
+
+You may also call align() before calling qr() to set alignment on the page.
+
+=head3 image
+
+Prints a GD image object to the printer
+
+     use GD;
+ 
+     my $img = newFromGif GD::Image('header.gif') || die "Error $!";
+     $device->printer->image($img);
+
 =head3 text
 
 Sends raw text to the printer.
@@ -170,9 +204,9 @@ Sends raw text to the printer.
 
 =head3 printAreaWidth
 
-Sets the Print area width specified by I<nL> and I<NH>. The width is calculated as 
+Sets the Print area width specified by I<nL> and I<NH>. The width is calculated as
 
-     ( nL + nH * 256 ) * horiz_motion_unit 
+     ( nL + nH * 256 ) * horiz_motion_unit
 
 A pre-requisite line feed is automatically executed before printAreaWidth method.
 
@@ -192,9 +226,10 @@ Default tab positions are usually in intervals of 8 chars (9, 17, 25) etc.
 
 =back
 
-=head3 tab 
+=head3 tab
 
-moves the cursor to next horizontal tab position like a C<<< "\t" >>>. This command is ignored unless the next horizontal tab position has been set. You may substitute this command with a C<<< "\t" >>> as well.
+moves the cursor to next horizontal tab position like a C<<< "\t" >>>. This command is ignored unless the next horizontal tab
+position has been set. You may substitute this command with a C<<< "\t" >>> as well.
 
 This
 
@@ -229,16 +264,16 @@ Set Font style, you can pass B<a>, B<b> or B<c>. Many printers don't support sty
      $device->printer->font('b');
      $device->printer->text('Writing in Font B');
 
-=head3 bold 
+=head3 bold
 
-Set bold mode B<0> for off and B<1> for on. Also called emphasized mode in some printer manuals 
+Set bold mode B<0> for off and B<1> for on. Also called emphasized mode in some printer manuals
 
      $device->printer->bold(1);
      $device->printer->text("This is Bold Text\n");
      $device->printer->bold(0);
      $device->printer->text("This is not Bold Text\n");
 
-=head3 doubleStrike 
+=head3 doubleStrike
 
 Set double-strike mode B<0> for off and B<1> for on
 
@@ -249,7 +284,7 @@ Set double-strike mode B<0> for off and B<1> for on
 
 =head3 underline
 
-set underline, B<0> for off, B<1> for on and B<2> for double thickness 
+set underline, B<0> for off, B<1> for on and B<2> for double thickness
 
      $device->printer->underline(1);
      $device->printer->text("This is Underlined Text\n");
@@ -269,33 +304,36 @@ Reverse whiteE<sol>black printing mode pass B<0> for off and B<1> for on
 
 =head3 color
 
-Most thermal printers support just one color, black. Some ESCPOS printers(especially dot matrix) also support a second color, usually red. In many models, this only works when the color is set at the beginning of a new line before any text is printed. Pass B<0> or B<1> to switch between the two colors.
+Most thermal printers support just one color, black. Some ESCPOS printers(especially dot matrix) also support a second
+color, usually red. In many models, this only works when the color is set at the beginning of a new line before any text
+is printed. Pass B<0> or B<1> to switch between the two colors.
 
      $device->printer->lf();
      $device->printer->color(0); #black
-     $device->printer->text("black"); 
+     $device->printer->text("black");
      $device->printer->lf();
      $device->printer->color(1); #red
-     $device->printer->text("Red"); 
+     $device->printer->text("Red");
      $device->printer->print();
 
-=head3 justify 
+=head3 justify
 
 Set Justification. Options B<left>, B<right> and B<center>
 
      $device->printer->justify( 'right' );
-     $device->printer->text("This is right justified"); 
+     $device->printer->text("This is right justified");
 
 =head3 upsideDown
 
 Sets Upside Down Printing onE<sol>off (pass B<0> or B<1>)
 
      $device->printer->upsideDownPrinting(1);
-     $device->printer->text("This text is upside down"); 
+     $device->printer->text("This text is upside down");
 
-=head3 fontHeight 
+=head3 fontHeight
 
-Set font height. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>, B<1>, B<2>, B<3>, B<4>, B<5>, B<6> and B<7> for non-printmode state (default) 
+Set font height. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>, B<1>, B<2>, B<3>, B<4>, B<5>, B<6> and
+B<7> for non-printmode state (default)
 
      $device->printer->fontHeight(1);
      $device->printer->text("double height\n");
@@ -305,9 +343,10 @@ Set font height. Only supports B<0> or B<1> for printmode set to 1, supports val
      $device->printer->text("quadruple height\n");
      . . .
 
-=head3 fontWidth 
+=head3 fontWidth
 
-Set font width. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>, B<1>, B<2>, B<3>, B<4>, B<5>, B<6> and B<7> for non-printmode state (default) 
+Set font width. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>, B<1>, B<2>, B<3>, B<4>, B<5>, B<6> and
+B<7> for non-printmode state (default)
 
      $device->printer->fontWidth(1);
      $device->printer->text("double width\n");
@@ -325,7 +364,7 @@ Sets character spacing. Takes a value between 0 and 255
      $device->printer->text("Blah Blah Blah\n");
      $device->printer->print();
 
-=head3 lineSpacing 
+=head3 lineSpacing
 
 Sets the line spacing i.e the spacing between each line of printout.
 
@@ -339,7 +378,7 @@ Sets the line spacing i.e the spacing between each line of printout.
 
 =back
 
-=head3 selectDefaultLineSpacing 
+=head3 selectDefaultLineSpacing
 
 Reverts to default line spacing for the printer
 
@@ -367,7 +406,9 @@ Sets the distance from the beginning of the line to the position at which charac
 
 Sets the left margin. Takes two single byte parameters, I<nL> and I<nH>.
 
-To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be effective.
+To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number)
+part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be
+effective.
 
 For example, to break the value 520 into two bytes, use the following two equations:
 I<nH> = INT 520E<sol>256
@@ -386,7 +427,8 @@ Rotate printout by 90 degrees
 
 =head3 barcode
 
-This method prints a barcode to the printer. This can be bundled with other text formatting commands at the appropriate point where you would like to print a barcode on your print out. takes argument I<barcode> as the barcode value.
+This method prints a barcode to the printer. This can be bundled with other text formatting commands at the appropriate
+point where you would like to print a barcode on your print out. takes argument I<barcode> as the barcode value.
 
 In the simplest form you can use this command as follows:
 
@@ -408,7 +450,7 @@ However there are several customizations available including barcode I<system>,
          height      => $height,        # no of dots in vertical direction
          system      => $system,        # Barcode system
          width       => 2               # 2:0.25mm, 3:0.375mm, 4:0.5mm, 5:0.625mm, 6:0.75mm
-         barcode     => '123456789012', # Check barcode system you are using for allowed 
+         barcode     => '123456789012', # Check barcode system you are using for allowed
                                         # characters in barcode
      );
      $device->printer->barcode(
@@ -456,17 +498,17 @@ CODABAR
 
 =item *
 
-CODE93  
+CODE93
 
 =item *
 
-CODE128 
+CODE128
 
 =back
 
 =head3 printNVImage
 
-Prints bit image stored in Non-Volatile (NV) memory of the printer. 
+Prints bit image stored in Non-Volatile (NV) memory of the printer.
 
      $device->printer->printNVImage($flag);
 
@@ -492,7 +534,7 @@ $flag = 3 # Double width and Double Height
 
 =head3 printImage
 
-Prints bit image stored in Volatile memory of the printer. This image gets erased when printer is reset. 
+Prints bit image stored in Volatile memory of the printer. This image gets erased when printer is reset.
 
      $device->printer->printImage($flag);
 
@@ -518,15 +560,20 @@ $flag = 3 # Double width and Double Height
 
 =head3 cutPaper
 
-Cuts the paper, if I<feed> is set to B<0> then printer doesnt feed paper to cutting position before cutting it. The default behavior is that the printer doesn't feed paper to cutting position before cutting. One pre-requisite line feed is automatically executed before paper cut though.
+Cuts the paper, if I<feed> is set to B<0> then printer doesnt feed paper to cutting position before cutting it. The
+default behavior is that the printer doesn't feed paper to cutting position before cutting. One pre-requisite line feed
+is automatically executed before paper cut though.
 
      $device->printer->cutPaper( feed => 0 )
 
-While not strictly a text formatting option, in receipt printer the cut paper instruction is sent along with the rest of the text and text formatting data and the printer cuts the paper at the appropriate points wherever this command is used.
+While not strictly a text formatting option, in receipt printer the cut paper instruction is sent along with the rest of
+the text and text formatting data and the printer cuts the paper at the appropriate points wherever this command is
+used.
 
 =head3 drawerKickPulse
 
-Trigger drawer kick. Used to open cash drawer connected to the printer. In some use cases it may be used to trigger other devices by close contact.
+Trigger drawer kick. Used to open cash drawer connected to the printer. In some use cases it may be used to trigger
+other devices by close contact.
 
      $device->printer->drawerKickPulse( $pin, $time );
 
@@ -546,22 +593,29 @@ For default values use without any params to kick drawer pin 2 with a 800ms puls
 
      $device->printer->drawerKickPulse();
 
-Again like cutPaper command this is obviously not a text formatting command but this command is sent along with the rest of the text and text formatting data and the printer sends the pulse at the appropriate points wherever this command is used. While originally designed for triggering a cash drawer to open, in practice this port can be used for all sorts of devices like pulsing light, or sound alarm etc.
+Again like cutPaper command this is obviously not a text formatting command but this command is sent along with the rest
+of the text and text formatting data and the printer sends the pulse at the appropriate points wherever this command is
+used. While originally designed for triggering a cash drawer to open, in practice this port can be used for all sorts of
+devices like pulsing light, or sound alarm etc.
 
 =head2 PRINTING
 
 =head3 print
 
-Once Initialization is done and the formatted text for printing is prepared using the above commands, its time to send these commands to printer. This is a single easy step.
+Once Initialization is done and the formatted text for printing is prepared using the above commands, its time to send
+these commands to printer. This is a single easy step.
 
      $device->printer->print();
 
 Why an extra print step to send this data to the printer?
-This is necessary because many printers have difficulty handling large amount of print data sent across in a single large stream. Separating the preparation of data from transmission of data to the printer allows L<Printer::ESCPOS> to do some buffer management and optimization in the way the entire data is sent to the printer with tiny timed breaks between chunks of data for a reliable printer output.
+This is necessary because many printers have difficulty handling large amount of print data sent across in a single
+large stream. Separating the preparation of data from transmission of data to the printer allows L<Printer::ESCPOS> to do
+some buffer management and optimization in the way the entire data is sent to the printer with tiny timed breaks between
+chunks of data for a reliable printer output.
 
 =head2 GETTING PRINTER HEALTH STATUS
 
-The B<Serial> I<driverType> allows reading of printer health, paper and other status parameters from the printer. 
+The B<Serial> I<driverType> allows reading of printer health, paper and other status parameters from the printer.
 At the moment there are following commands available for getting printer status.
 
 =head3 printerStatus
@@ -577,7 +631,8 @@ Returns printer status in a hashref.
 
 =head3 offlineStatus
 
-Returns a hashref for paper cover closed status, feed button pressed status, paper end stop status, and a aggregate error status either of which will prevent the printer from processing a printing request.
+Returns a hashref for paper cover closed status, feed button pressed status, paper end stop status, and a aggregate
+error status either of which will prevent the printer from processing a printing request.
 
      return {
          cover_is_closed     => $flags[5],
@@ -598,7 +653,9 @@ Returns hashref with error flags for auto_cutter_error, unrecoverable error and
 
 =head3 paperSensorStatus
 
-Gets printer paper Sensor status. Returns a hashref with four sensor statuses. Two paper near end sensors and two paper end sensors for printers supporting this feature. The exact returned status might differ based on the make of your printer. If any of the flags is set to 1 it implies that the paper is out or near end.
+Gets printer paper Sensor status. Returns a hashref with four sensor statuses. Two paper near end sensors and two paper
+end sensors for printers supporting this feature. The exact returned status might differ based on the make of your
+printer. If any of the flags is set to 1 it implies that the paper is out or near end.
 
      return {
          paper_roll_near_end_sensor_1 => $flags[5],
@@ -609,7 +666,8 @@ Gets printer paper Sensor status. Returns a hashref with four sensor statuses. T
 
 =head3 inkStatusA
 
-Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkA(usually black ink). Returns a hashref with ink statuses.
+Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkA(usually black ink).
+Returns a hashref with ink statuses.
 
      return {
          ink_near_end          => $flags[5],
@@ -620,7 +678,8 @@ Only available for dot-matrix and other ink consuming printers. Gets printer ink
 
 =head3 inkStatusB
 
-Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkB(usually red ink). Returns a hashref with ink statuses.
+Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkB(usually red ink).
+Returns a hashref with ink statuses.
 
      return {
          ink_near_end          => $flags[5],
