@@ -13,13 +13,14 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 # Dependencies
 use 5.010;
 use Moo;
 with 'Printer::ESCPOS::Roles::Profile';
 use Carp;
+use GD::Barcode::QRcode;
 
 use constant {
     _ESC => "\x1b",
@@ -54,6 +55,20 @@ sub enable {
 }
 
 
+sub qr {
+    my ( $self, $string, $ecc, $version, $moduleSize ) = @_;
+    $ecc        ||= 'L';
+    $version    ||= 5;
+    $moduleSize ||= 3;
+
+    my $qrImage =
+      GD::Barcode::QRcode->new( $string,
+        { Ecc => $ecc, Version => $version, ModuleSize => $moduleSize } )
+      ->plot();
+    $self->image($qrImage);
+}
+
+
 sub image {
     my ( $self, $img ) = @_;
     my $paddingLeft  = '';
@@ -597,22 +612,43 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for L<Printer:
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 METHODS
 
 =head2 init
 
-Initializes the Printer. Clears the data in print buffer and resets the printer to the mode that was in effect when the power was turned on. This function is automatically called on creation of printer object.
+Initializes the Printer. Clears the data in print buffer and resets the printer to the mode that was in effect when the
+power was turned on. This function is automatically called on creation of printer object.
 
 =head2 enable
 
-Enables/Disables the printer with a '_ESC =' command (Set peripheral device). When disabled, the printer ignores all commands except enable() or other real-time commands.
+Enables/Disables the printer with a '_ESC =' command (Set peripheral device). When disabled, the printer ignores all
+commands except enable() or other real-time commands.
+
 Pass 1 to enable, pass 0 to disable
 
     $device->printer->enable(0) # disabled
     $device->printer->enable(1) # enabled
 
+=head2 qr
+
+Prints a qr code to the printer. In Generic profile, this creates a QR Code image using L<GD::Barcode::QRcode>. A native
+implementation may be created using a printer model specific profile.
+
+    $device->printer->qr('Print this QR Code');
+    $device->printer->qr('WIFI:T:WPA;S:ShantanusWifi;P:wifipasswordhere;;')  # Create a QR code for connecting to a Wifi
+
+You may also pass in optional QR Code format parameters like Ecc, Version and moduleSize. Read more about these params
+at L<http://www.qrcode.com/en/about/version.html>.
+
+    my $ecc = 'L'; # Default value
+    my $version = 5; # Default value
+    my $moduleSize = 3; # Default value
+    $device->printer->qr("Don't Panic!", $ecc, $version, $moduleSize);
+
+You may also call align() before calling qr() to set alignment on the page.
+
 =head2 image
 
 Prints a image to the printer. Takes a L<GD> Image object as input. <Maximum printable image dimensions are 512x255
@@ -622,6 +658,8 @@ Prints a image to the printer. Takes a L<GD> Image object as input. <Maximum pri
     my $img = newFromGif GD::Image('header.gif') || die "Error $!";
     $device->printer->image($img);
 
+You may also call align() before calling qr() to set alignment on the page.
+
 =head2 printAreaWidth
 
 Sets the Print area width specified by nL and NH. The width is calculated as
@@ -641,7 +679,8 @@ Sets horizontal tab positions for tab stops. Upto 32 tab positions can be set in
 
 =head2 tab
 
-moves the cursor to next horizontal tab position like a "\t". This command is ignored unless the next horizontal tab position has been set. You may substitute this command with a "\t" as well.
+moves the cursor to next horizontal tab position like a "\t". This command is ignored unless the next horizontal tab
+position has been set. You may substitute this command with a "\t" as well.
 
 This
 
@@ -730,7 +769,9 @@ Reverse white/black printing mode pass *0* for off and *1* for on
 
 =head2 color
 
-Most thermal printers support just one color, black. Some ESCPOS printers(especially dot matrix) also support a second color, usually red. In many models, this only works when the color is set at the beginning of a new line before any text is printed. Pass *0* or *1* to switch between the two colors.
+Most thermal printers support just one color, black. Some ESCPOS printers(especially dot matrix) also support a second
+color, usually red. In many models, this only works when the color is set at the beginning of a new line before any text
+is printed. Pass *0* or *1* to switch between the two colors.
 
     $device->printer->lf();
     $device->printer->color(0); #black
@@ -756,7 +797,8 @@ Sets Upside Down Printing on/off (pass *0* or *1*)
 
 =head2 fontHeight
 
-Set font height. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and *7* for non-printmode state (default)
+Set font height. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and
+*7* for non-printmode state (default)
 
     $device->printer->fontHeight(1);
     $device->printer->text("double height\n");
@@ -768,7 +810,8 @@ Set font height. Only supports *0* or *1* for printmode set to 1, supports value
 
 =head2 fontWidth
 
-Set font width. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and *7* for non-printmode state (default)
+Set font width. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and
+*7* for non-printmode state (default)
 
     $device->printer->fontWidth(1);
     $device->printer->text("double width\n");
@@ -813,7 +856,9 @@ Sets the distance from the beginning of the line to the position at which charac
 
 Sets the left margin. Takes two single byte parameters, ~nL~ and ~nH~.
 
-To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be effective.
+To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number)
+part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be
+effective.
 
 For example, to break the value 520 into two bytes, use the following two equations:
 ~nH~ = INT 520/256
@@ -832,7 +877,8 @@ Rotate printout by 90 degrees
 
 =head2 barcode
 
-This method prints a barcode to the printer. This can be bundled with other text formatting commands at the appropriate point where you would like to print a barcode on your print out. takes argument ~barcode~ as the barcode value.
+This method prints a barcode to the printer. This can be bundled with other text formatting commands at the appropriate
+point where you would like to print a barcode on your print out. takes argument ~barcode~ as the barcode value.
 
 In the simplest form you can use this command as follows:
 
@@ -904,15 +950,20 @@ Prints bit image stored in Volatile memory of the printer. This image gets erase
 
 =head2 cutPaper
 
-Cuts the paper, if ~feed~ is set to *0* then printer doesnt feed paper to cutting position before cutting it. The default behavior is that the printer doesn't feed paper to cutting position before cutting. One pre-requisite line feed is automatically executed before paper cut though.
+Cuts the paper, if ~feed~ is set to *0* then printer doesnt feed paper to cutting position before cutting it. The
+default behavior is that the printer doesn't feed paper to cutting position before cutting. One pre-requisite line feed
+is automatically executed before paper cut though.
 
     $device->printer->cutPaper( feed => 0 )
 
-While not strictly a text formatting option, in receipt printer the cut paper instruction is sent along with the rest of the text and text formatting data and the printer cuts the paper at the appropriate points wherever this command is used.
+While not strictly a text formatting option, in receipt printer the cut paper instruction is sent along with the rest of
+the text and text formatting data and the printer cuts the paper at the appropriate points wherever this command is
+used.
 
 =head2 drawerKickPulse
 
-Trigger drawer kick. Used to open cash drawer connected to the printer. In some use cases it may be used to trigger other devices by close contact.
+Trigger drawer kick. Used to open cash drawer connected to the printer. In some use cases it may be used to trigger
+other devices by close contact.
 
     $device->printer->drawerKickPulse( $pin, $time );
 
@@ -923,7 +974,10 @@ For default values use without any params to kick drawer pin 2 with a 800ms puls
 
     $device->printer->drawerKickPulse();
 
-Again like cutPaper command this is obviously not a text formatting command but this command is sent along with the rest of the text and text formatting data and the printer sends the pulse at the appropriate points wherever this command is used. While originally designed for triggering a cash drawer to open, in practice this port can be used for all sorts of devices like pulsing light, or sound alarm etc.
+Again like cutPaper command this is obviously not a text formatting command but this command is sent along with the rest
+of the text and text formatting data and the printer sends the pulse at the appropriate points wherever this command is
+used. While originally designed for triggering a cash drawer to open, in practice this port can be used for all sorts of
+devices like pulsing light, or sound alarm etc.
 
 =head2 printerStatus
 
@@ -938,7 +992,8 @@ Returns printer status in a hashref.
 
 =head2 offlineStatus
 
-Returns a hashref for paper cover closed status, feed button pressed status, paper end stop status, and a aggregate error status either of which will prevent the printer from processing a printing request.
+Returns a hashref for paper cover closed status, feed button pressed status, paper end stop status, and a aggregate
+error status either of which will prevent the printer from processing a printing request.
 
     return {
         cover_is_closed     => $flags[5],
@@ -959,7 +1014,9 @@ Returns hashref with error flags for auto_cutter_error, unrecoverable error and
 
 =head2 paperSensorStatus
 
-Gets printer paper Sensor status. Returns a hashref with four sensor statuses. Two paper near end sensors and two paper end sensors for printers supporting this feature. The exact returned status might differ based on the make of your printer. If any of the flags is set to 1 it implies that the paper is out or near end.
+Gets printer paper Sensor status. Returns a hashref with four sensor statuses. Two paper near end sensors and two paper
+end sensors for printers supporting this feature. The exact returned status might differ based on the make of your
+printer. If any of the flags is set to 1 it implies that the paper is out or near end.
 
     return {
         paper_roll_near_end_sensor_1 => $flags[5],
@@ -970,7 +1027,8 @@ Gets printer paper Sensor status. Returns a hashref with four sensor statuses. T
 
 =head2 inkStatusA
 
-Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkA(usually black ink). Returns a hashref with ink statuses.
+Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkA(usually black ink).
+Returns a hashref with ink statuses.
 
     return {
         ink_near_end          => $flags[5],
@@ -981,7 +1039,8 @@ Only available for dot-matrix and other ink consuming printers. Gets printer ink
 
 =head2 inkStatusB
 
-Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkB(usually red ink). Returns a hashref with ink statuses.
+Only available for dot-matrix and other ink consuming printers. Gets printer ink status for inkB(usually red ink).
+Returns a hashref with ink statuses.
 
     return {
         ink_near_end          => $flags[5],
