@@ -13,7 +13,7 @@ package Printer::ESCPOS::Roles::Connection;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 # Dependencies
 
@@ -66,20 +66,22 @@ Printer::ESCPOS::Roles::Connection - Role for Connection Classes for L<Printer::
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 METHODS
 
 =head2 write
 
-Writes prepared data to the module buffer. This data is dispatched to printer with print() method. The print method takes care of buffer control issues.
+Writes prepared data to the module buffer. This data is dispatched to printer with print() method. The print method
+takes care of buffer control issues.
 
 =head2 print
 
-If a string is passed then it passes the string to the printer else passes the buffer data to the printer and clears the buffer.
+If a string is passed then it passes the string to the printer else passes the buffer data to the printer and clears
+the buffer.
 
     $device->printer->print(); # Prints and clears the Buffer.
-    $device->printer->print($raw); # Prints $raw 
+    $device->printer->print($raw); # Prints $raw
 
 =head1 AUTHOR
 
